const http = {
  async request(method, url, data, headers = {}) {
    try {
      const defaultHeaders = {
        'Accept': 'application/json',
        'Content-Type': 'application/json',
      }

      headers = Object.assign(defaultHeaders, headers);

      const options = {
        method: method,
        headers,
      }

      if (data instanceof FormData) {
        options.body = data;
        delete options.headers['Accept'];
        delete options.headers['Content-Type'];
      } else {
        options.body = JSON.stringify(data);
      }

      if (method === 'GET') {
        delete options.body;
      }

      return await fetch(url, options)

    } catch (e) {
      console.error(e)
    }
  },

  async get(url, headers = {}) {
    return await this.request('GET', url, null, headers);
  },

  async post(url, data, headers) {
    return await this.request('POST', url, data, headers);
  },

  async put(url, data, headers) {
    return await this.request('PUT', url, data, headers);
  },

  async delete(url, data, headers) {
    return await this.request('DELETE', url, data, headers);
  },
}

export default http;
